==> v1.6.0.tar.gz: helenaexpressapp/www/routes.js <==
/*
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

var compiledPages = {};
var pagesToCompile = [
    "home",
    "welcome",
    "appointment",
    "dropandsend",
    "pickup",
    "rateresult",
    "account",
    "trackresult",
    "settings"
];
console.log("Compiling page templates...");
for (var i = 0; i < pagesToCompile.length; i++) {
    compiledPages[pagesToCompile[i]] = Template7.compile($.ajax({
        type: "GET",
        url: "./pages/" + pagesToCompile[i] + ".html",
        async: false
    }).responseText);
}
console.log("Compiled page templates.");

var routes = [
    {
        path: '/welcome',
        content: compiledPages.welcome(),
        name: 'welcome',
        on: {
            pageAfterIn: function () {

            }
        }
    },
    {
        path: '/home',
        name: 'home',
        on: {
            pageBeforeIn: function () {
                // make sure it's not shown right after account setup
                var accountsetup = (inStorage("accountkey") && inStorage("accountnumber"));
                if (accountsetup) {
                    $("#finishaccountsetupnag").css("display", "none");
                }
            }
        },
        async: function ( { resolve, reject }) {
            // Show a nag message if no account is set up
            var accountsetup = (inStorage("accountkey") && inStorage("accountnumber")) || getStorage("hideaccountnag") == "true";
            // add escape hatch to regular website if running online
            var escapehatch = false;
            if (window.location.hostname == "app.helena.express") {
                escapehatch = true;
            }
            resolve({
                content: compiledPages.home({
                    accountsetup: accountsetup,
                    escapehatch: escapehatch,
                    pages: [
                        {
                            title: "Package Pickup",
                            href: "/pickup",
                            icon: "fad fa-boxes",
                            text: "Leave your package somewhere and we'll pick it up and ship it for you. No postage or appointment needed."
                        },
                        {
                            title: "Drop and Send",
                            href: "/dropandsend",
                            icon: "fad fa-box-alt",
                            text: "Bring your package to a secure drop location and we'll ship it for you. No postage or appointment needed."
                        },
                        {
                            title: "Book Appointment",
                            href: "/appointment",
                            icon: "fad fa-calendar-alt",
                            text: "Get mailing, shipping, and notary services on your schedule anywhere in the Helena area."
                        },
                        {
                            title: "My Account",
                            href: "/account",
                            icon: "fad fa-user-circle",
                            text: "Manage your Helena Express account and check rewards points balance."
                        },
                        {
                            title: "Send a Telegram",
                            href: "/telegram",
                            icon: "fad fa-typewriter",
                            text: "Send a telegram anywhere in the Helena area. Hand-delivered within 24 hours."
                        }
                    ]
                })
            }, {});
        }
    },
    {
        path: '/appointment',
        name: 'appointment',
        async: function ( { resolve, reject }) {
            resolve({
                content: compiledPages.appointment({
                    services: [
                        {
                            title: "Package Pickup",
                            text: "A courier will come to you and ship your mail, packages, etc.",
                            icon: "fad fa-hand-holding-box",
                            serviceid: 19
                        },
                        {
                            title: "Mobile Notary",
                            text: "A notary public will come to you and notarize your documents.",
                            icon: "fad fa-file-signature",
                            serviceid: 21
                        }
                    ]
                })
            }, {
            });
        },
        routes: [
            {
                path: "/:serviceId",
                async: function ( { resolve, reject, to }) {
                    var url = SETTINGS.appointmenturl;
                    if ($("#app").hasClass("theme-dark")) {
                        url = SETTINGS.appointmenturl_darkmode;
                    }
                    resolve({
                        content: compiledPages.appointment({
                            url: url + "&service=" + to.params.serviceId
                        })
                    }, {
                    });
                }
            }
        ]
    },
    {
        path: '/dropandsend',
        name: 'dropandsend',
        content: compiledPages.dropandsend(),
        on: {
            pageBeforeIn: function () {
                checkIfAccountGoodWithPaymentMethod(function (ok) {
                    if (!ok) {
                        $("#addPaymentMethodNag").css("display", "");
                    }
                }, function (error) {
                    $("#addPaymentMethodNag").css("display", "");
                });
            },
            pageAfterOut: function () {
                dropboxMap = null;
            }
        }
    },
    {
        path: '/pickup',
        name: 'pickup',
        async: function ( {resolve}) {
            resolve({
                content: compiledPages.pickup({
                    streetaddress: inStorage("lastpickupaddress") ? getStorage("lastpickupaddress") : "",
                    zipcode: inStorage("lastpickupzipcode") ? getStorage("lastpickupzipcode") : ""
                })
            }, {});
        },
        on: {
            pageBeforeIn: function () {
                checkIfAccountGoodWithPaymentMethod(function (ok) {
                    if (!ok) {
                        $("#addPaymentMethodNag").css("display", "");
                    }
                }, function (error) {
                    $("#addPaymentMethodNag").css("display", "");
                });
            }
        }
    },
    {
        path: '/telegram',
        name: 'telegram',
        url: './pages/telegram.html',
        on: {
            pageBeforeIn: function () {
                checkIfAccountGoodWithPaymentMethod(function (ok) {
                    if (!ok) {
                        $("#addPaymentMethodNag").css("display", "");
                    }
                }, function (error) {
                    $("#addPaymentMethodNag").css("display", "");
                });
            }
        }
    },
    {
        path: '/track',
        url: './pages/track.html',
        name: 'track',
        on: {
            pageBeforeIn: function () {
                addTrackingSuggestions();
                $("#trackingcode").val("0");
                app.input.validate("#trackingcode");
                $("#trackingcode").val("");
            }
        }
    },
    {
        path: '/rates',
        url: './pages/rates.html',
        name: 'rates',
        on: {
            pageAfterIn: function () {
                initRateForm();
            }
        }
    },
    {
        path: '/account',
        name: 'account',
        content: compiledPages.account(),
        on: {
            pageAfterIn: function () {
                initAccountPage();
            }
        }
    },
    {
        path: '/track/:code',
        name: 'trackresult',
        async: trackOpenAsync,
        on: {
            pageAfterIn: function () {
                var mapboxel = document.getElementById("mapbox-track");
                var trackingMap = new MapControl(mapboxel, false);
                trackingMap.reloadMap();
                var latitude = $(mapboxel).data("latitude");
                var longitude = $(mapboxel).data("longitude");
                var accurate = $(mapboxel).data("accurate") == true;
                trackingMap.clearMarkersAndCenterMapOnNewMarker("package-marker", latitude, longitude, accurate);
            }
        }
    },
    {
        path: '/credits',
        url: './pages/credits.html',
        name: 'credits'
    },
    {
        path: '/settings',
        name: 'settings',
        async: function ( {resolve}) {
            var settings = [];
            settings.push(
                    {
                        setting: "display",
                        title: "Display and Appearance",
                        text: "",
                        onclick: "router.navigate('/settings/display')",
                        link: true
                    }
            );

            settings.push(
                    {
                        setting: "resetaccount",
                        title: "Forget Account",
                        text: "Log out and disconnect from your Helena Express account.",
                        onclick: "resetAccountPrompt()",
                        link: true
                    },
                    {
                        setting: "versions",
                        title: "Helena Express app v" + app_version,
                        text: "Copyright &copy; 2019-2021 Netsyms Technologies.",
                        onclick: ""
                    },
                    {
                        setting: "opensource",
                        title: "Credits and open source info",
                        text: "",
                        onclick: "router.navigate('/credits')",
                        link: true
                    },
                    {
                        setting: "privacy",
                        title: "Privacy policy and legal",
                        text: "",
                        onclick: "openBrowser('https://netsyms.com/legal?mtm_campaign=HelenaExpressApp')",
                        link: true
                    });
            resolve({
                content: compiledPages.settings({
                    page_title: "Settings",
                    settings: settings
                })
            });
        },
        routes: [
            {
                path: '/display',
                name: 'settings',
                async: function ( {resolve}) {
                    var settings = [
                        {
                            setting: "apptheme",
                            title: "Color theme",
                            select: true,
                            options: [
                                {
                                    value: "auto",
                                    label: "Auto",
                                    selected: getStorage("apptheme") == null || getStorage("apptheme") == "auto"
                                },
                                {
                                    value: "dark",
                                    label: "Dark",
                                    selected: getStorage("apptheme") == "dark"
                                },
                                {
                                    value: "light",
                                    label: "Light",
                                    selected: getStorage("apptheme") == "light"
                                }
                            ]
                        },
                        {
                            setting: "animation",
                            title: "Animations",
                            select: true,
                            options: [
                                {
                                    value: "auto",
                                    label: "On",
                                    selected: getStorage("animation") == null || getStorage("animation") == "auto" || getStorage("animation") == "on"
                                },
//                                {
//                                    value: "on",
//                                    label: "On",
//                                    selected: getStorage("animation") == "on"
//                                },
                                {
                                    value: "off",
                                    label: "Off",
                                    selected: getStorage("animation") == "off"
                                }
                            ]
                        },
                        {
                            setting: "hideaccountnag",
                            title: "Hide \"Finish Account Setup\"",
                            text: "",
                            toggle: true,
                            checked: getStorage("hideaccountnag") == "true",
                            onclick: ""
                        }
                    ];
                    resolve({
                        content: compiledPages.settings({
                            page_title: "Display Settings",
                            settings: settings
                        })
                    });
                }
            }
        ]
    }
];

==> V1.7.0.tar.gz: helenaexpressapp/www/routes.js <==
/*
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

var compiledPages = {};
var pagesToCompile = [
    "home",
    "send",
    "welcome",
    "appointment",
    "dropandsend",
    "pickup",
    "shop",
    "shoppingcart_fragment",
    "rateresult",
    "account",
    "trackresult",
    "settings"
];
console.log("Compiling page templates...");
for (var i = 0; i < pagesToCompile.length; i++) {
    compiledPages[pagesToCompile[i]] = Template7.compile($.ajax({
        type: "GET",
        url: "./pages/" + pagesToCompile[i] + ".html",
        async: false
    }).responseText);
}
console.log("Compiled page templates.");

var routes = [
    {
        path: '/welcome',
        content: compiledPages.welcome(),
        name: 'welcome',
        on: {
            pageAfterIn: function () {

            }
        }
    },
    {
        path: '/home',
        name: 'home',
        alias: ["/"],
        on: {
            pageBeforeIn: function () {
                // make sure it's not shown right after account setup
                var accountsetup = (inStorage("accountkey") && inStorage("accountnumber"));
                if (accountsetup) {
                    $("#finishaccountsetupnag").css("display", "none");
                }
            }
        },
        async: function ( { resolve, reject }) {
            // Show a nag message if no account is set up
            var accountsetup = (inStorage("accountkey") && inStorage("accountnumber")) || getStorage("hideaccountnag") == "true";
            // add escape hatch to regular website if running online
            var escapehatch = false;
            if (window.location.hostname == "app.helena.express") {
                escapehatch = true;
            }
            resolve({
                content: compiledPages.home({
                    accountsetup: accountsetup,
                    escapehatch: escapehatch,
                    pages: [
                        {
                            title: "Send a Package",
                            href: "/send",
                            icon: "fad fa-boxes",
                            text: "Find a drop box or schedule a pickup."
                        },
                        {
                            title: "Notarize a Document",
                            href: "/appointment/notary",
                            icon: "fad fa-file-signature",
                            text: "Book a mobile notary visit."
                        },
                        {
                            title: "Write a Telegram",
                            href: "/telegram",
                            icon: "fad fa-typewriter",
                            text: "Send a hand-delivered telegram anywhere in the Helena area."
                        },
                        {
                            title: "Shop for Supplies",
                            href: "/shop",
                            icon: "fad fa-shopping-cart",
                            text: "Get boxes, labels, and shipping supplies delivered to your door."
                        },
                        {
                            title: "Manage My Account",
                            href: "/account",
                            icon: "fad fa-user-circle",
                            text: "Get account number, check rewards points, update payment method, and more."
                        },
                    ]
                })
            }, {});
        }
    },
    {
        path: '/send',
        name: 'send',
        async: function ( { resolve, reject }) {
            resolve({
                content: compiledPages.send({
                    pages: [
                        {
                            title: "Use a Drop Box",
                            href: "/dropandsend",
                            icon: "fad fa-box-alt",
                            text: "Bring your package to a Drop and Send location and we'll ship it for you. No postage or appointment needed."
                        },
                        {
                            title: "Request a Pickup",
                            href: "/pickup",
                            icon: "fad fa-home",
                            text: "Leave your package on your porch and we'll pick it up and ship it for you. No postage or appointment needed."
                        },
                        {
                            title: "Book an Appointment",
                            href: "/appointment/shipping",
                            icon: "fad fa-calendar-alt",
                            text: "A courier will come to you on your schedule. No account required."
                        }
                    ]
                })
            }, {});
        }
    },
    {
        path: '/appointment',
        name: 'appointment',
        async: function ( { resolve, reject }) {
            resolve({
                content: compiledPages.appointment({
                    services: [
                        {
                            title: "Package Pickup",
                            text: "A courier will come to you and ship your mail, packages, etc.",
                            icon: "fad fa-hand-holding-box",
                            serviceid: "shipping"
                        },
                        {
                            title: "Mobile Notary",
                            text: "A notary public will come to you and notarize your documents.",
                            icon: "fad fa-file-signature",
                            serviceid: "notary"
                        }
                    ]
                })
            }, {
            });
        },
        routes: [
            {
                path: "/:serviceId",
                async: function ( { resolve, reject, to }) {
                    var url = SETTINGS.apis.appointmentredirect + "?service=" + to.params.serviceId;
                    if ($("body").hasClass("theme-dark")) {
                        url += "&darkmode=1";
                    }
                    resolve({
                        content: compiledPages.appointment({
                            url: url,
                            serviceid: to.params.serviceId
                        })
                    }, {
                    });
                }
            }
        ]
    },
    {
        path: '/dropandsend',
        name: 'dropandsend',
        content: compiledPages.dropandsend(),
        on: {
            pageBeforeIn: function () {
                checkIfAccountGoodWithPaymentMethod(function (ok) {
                    if (!ok) {
                        $("#addPaymentMethodNag").css("display", "");
                    }
                }, function (error) {
                    $("#addPaymentMethodNag").css("display", "");
                });
            },
            pageAfterOut: function () {
                dropboxMap = null;
            }
        }
    },
    {
        path: '/pickup',
        name: 'pickup',
        async: function ( {resolve}) {
            resolve({
                content: compiledPages.pickup({
                    streetaddress: inStorage("lastpickupaddress") ? getStorage("lastpickupaddress") : "",
                    zipcode: inStorage("lastpickupzipcode") ? getStorage("lastpickupzipcode") : ""
                })
            }, {});
        },
        on: {
            pageBeforeIn: function () {
                checkIfAccountGoodWithPaymentMethod(function (ok) {
                    if (!ok) {
                        $("#addPaymentMethodNag").css("display", "");
                    }
                }, function (error) {
                    $("#addPaymentMethodNag").css("display", "");
                });
            }
        }
    },
    {
        path: '/shop',
        name: 'shop',
        async: loadShopPage,
        on: {
            pageBeforeIn: function () {
                checkIfAccountGoodWithPaymentMethod(function (ok) {
                    if (!ok) {
                        $("#addPaymentMethodNag").css("display", "");
                    }
                }, function (error) {
                    $("#addPaymentMethodNag").css("display", "");
                });
                updateCart();
            }
        }
    },
    {
        path: '/telegram',
        name: 'telegram',
        url: './pages/telegram.html',
        on: {
            pageBeforeIn: function () {
                checkIfAccountGoodWithPaymentMethod(function (ok) {
                    if (!ok) {
                        $("#addPaymentMethodNag").css("display", "");
                    }
                }, function (error) {
                    $("#addPaymentMethodNag").css("display", "");
                });
            }
        }
    },
    {
        path: '/track',
        url: './pages/track.html',
        name: 'track',
        on: {
            pageBeforeIn: function () {
                addTrackingSuggestions();
                $("#trackingcode").val("0");
                app.input.validate("#trackingcode");
                $("#trackingcode").val("");
            }
        }
    },
    {
        path: '/rates',
        url: './pages/rates.html',
        name: 'rates',
        on: {
            pageAfterIn: function () {
                initRateForm();
            }
        }
    },
    {
        path: '/account',
        name: 'account',
        content: compiledPages.account(),
        on: {
            pageAfterIn: function () {
                initAccountPage();
            }
        }
    },
    {
        path: '/track/:code',
        name: 'trackresult',
        async: trackOpenAsync,
        on: {
            pageAfterIn: function () {
                var mapboxel = document.getElementById("mapbox-track");
                var trackingMap = new MapControl(mapboxel, false);
                trackingMap.reloadMap();
                var latitude = $(mapboxel).data("latitude");
                var longitude = $(mapboxel).data("longitude");
                var accurate = $(mapboxel).data("accurate") == true;
                trackingMap.clearMarkersAndCenterMapOnNewMarker("package-marker", latitude, longitude, accurate);
            }
        }
    },
    {
        path: '/credits',
        url: './pages/credits.html',
        name: 'credits'
    },
    {
        path: '/settings',
        name: 'settings',
        async: function ( {resolve}) {
            var settings = [];
            settings.push(
                    {
                        setting: "display",
                        title: "Display and Appearance",
                        text: "",
                        onclick: "router.navigate('/settings/display')",
                        link: true
                    }
            );

            settings.push(
                    {
                        setting: "resetaccount",
                        title: "Forget Account",
                        text: "Log out and disconnect from your Helena Express account.",
                        onclick: "resetAccountPrompt()",
                        link: true
                    },
                    {
                        setting: "versions",
                        title: "Helena Express app v" + app_version,
                        text: "Copyright &copy; 2019-2022 Helena Express and Netsyms Technologies.",
                        onclick: ""
                    },
                    {
                        setting: "opensource",
                        title: "Credits and open source info",
                        text: "",
                        onclick: "router.navigate('/credits')",
                        link: true
                    },
                    {
                        setting: "legal",
                        title: "Terms of Use and Privacy Policy",
                        text: "",
                        onclick: "openBrowser('https://helena.express/appterms?mtm_campaign=HelenaExpressApp')",
                        link: true
                    },
                    {
                        setting: "analytics",
                        title: "Analytics",
                        text: "If turned on, we'll collect some anonymous information to help improve the app. It is not sent to any third parties.",
                        toggle: true,
                        checked: getStorage("analytics") !== "false",
                        onclick: ""
                    }, );
            resolve({
                content: compiledPages.settings({
                    page_title: "Settings",
                    settings: settings
                })
            });
        },
        routes: [
            {
                path: '/display',
                name: 'settings',
                async: function ( {resolve}) {
                    var settings = [
                        {
                            setting: "apptheme",
                            title: "Color theme",
                            select: true,
                            options: [
                                {
                                    value: "auto",
                                    label: "Auto",
                                    selected: getStorage("apptheme") == null || getStorage("apptheme") == "auto"
                                },
                                {
                                    value: "dark",
                                    label: "Dark",
                                    selected: getStorage("apptheme") == "dark"
                                },
                                {
                                    value: "light",
                                    label: "Light",
                                    selected: getStorage("apptheme") == "light"
                                }
                            ]
                        },
                        {
                            setting: "animation",
                            title: "Animations",
                            select: true,
                            options: [
                                {
                                    value: "auto",
                                    label: "On",
                                    selected: getStorage("animation") == null || getStorage("animation") == "auto" || getStorage("animation") == "on"
                                },
//                                {
//                                    value: "on",
//                                    label: "On",
//                                    selected: getStorage("animation") == "on"
//                                },
                                {
                                    value: "off",
                                    label: "Off",
                                    selected: getStorage("animation") == "off"
                                }
                            ]
                        },
                        {
                            setting: "hideaccountnag",
                            title: "Hide \"Finish Account Setup\"",
                            text: "",
                            toggle: true,
                            checked: getStorage("hideaccountnag") == "true",
                            onclick: ""
                        }
                    ];
                    resolve({
                        content: compiledPages.settings({
                            page_title: "Display Settings",
                            settings: settings
                        })
                    });
                }
            }
        ]
    },
    {
        path: '(.*)',
        url: './pages/404.html',
        name: '404'
    }
];
